#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IF_ALLBITS_ELSE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IF_ALLBITS_ELSE_HPP_INCLUDED

#include <boost/simd/boolean/include/functions/scalar/if_allbits_else.hpp>

#endif
